@@ -252,7 +252,7 @@ def ensure_git_bash() -> Path:
 
         # No installation found, download a portable installation
         print('Git installation not found. Git is required to use HyFetch/neofetch on Windows')
-        if literal_input('Would you like to install a minimal package for Git? (if no is selected colors almost certianly won\'t work)', ['yes', 'no'], 'yes', False) == 'yes':
+        if literal_input('Would you like to install a minimal package for Git? (if no is selected colors almost certainly won\'t work)', ['yes', 'no'], 'yes', False) == 'yes':
             print('Downloading a minimal portable package for Git...')
             from urllib.request import urlretrieve
             urlretrieve(MINGIT_URL, pkg_path)
@@ -345,8 +345,30 @@ def run(asc: str, backend: BackendLiteral, args: str = ''):
         return run_fastfetch(asc, args)
     if backend == "fastfetch-old":
         return run_fastfetch(asc, args, legacy=True)
+    if backend == "qwqfetch":
+        return run_qwqfetch(asc, args)
 
 
+def run_qwqfetch(asc: str, args: str = ''):
+    """
+    Run neofetch with colors
+
+    :param preset: Color palette
+    :param alignment: Color alignment settings
+    """
+    asc = asc.replace('\\', '\\\\')
+
+    # call qwqfetch to print string
+    try:
+        import qwqfetch
+        # distro_detector only return a bash variable
+        # so we use qwqfetch builtin distro detector
+        print(qwqfetch.get_ascres(asc))  
+    except ImportError as e:  # module not found etc
+        print("qwqfetch is not installed. Install it by executing:")  # use print to output hint directly
+        print("pip install git+https://github.com/nexplorer-3e/qwqfetch")  # TODO: public repo
+        raise e
+
 def run_neofetch(asc: str, args: str = ''):
     """
     Run neofetch with colors
@@ -402,7 +424,7 @@ def get_fore_back(distro: str | None = None) -> tuple[int, int] | None:
         distro = get_distro_name().lower()
     distro = distro.lower().replace(' ', '-')
     for k, v in fore_back.items():
-        if distro == k.lower():
+        if distro.startswith(k.lower()):
             return v
     return None
 
